/******************************************************************************
 *
 * FILE: dspi.h
 *
 * Description:
 *    SPI communication (Master mode send/receive)
 *
 * History:
 *    17.11.2017   PN   Initial version
 *    13.02.2018   MF   Reuse for SPC574K72
 *
 *
 ******************************************************************************
 * Copyright (C) 2015-2017 HighTec EDV-Systeme GmbH.  All rights reserved.
 *
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/


#ifndef DSPI_H
#define DSPI_H

/* ============================================================================
 * DSPI EXAMPLE SETTING
 * User ** can ** change it, here in this file
 * ==========================================================================*/

/* ============================================================================
 * DSPI, PIN INSTANCES IMPLEMENTATION
 * Only relevant configuration for DSPI example
 * ==========================================================================*/

/* DSPI PUSH FIFO register configuration */
#define DSPI_PUSHR_PCS    0x01  /* Selects PCS0 signal to be asserted for the
                                   transfer */
#define DSPI_PUSHR_PP     0x0   /* PP: Even Parity */
#define DSPI_PUSHR_PE     0x0   /* PE: No parity bit included/checked.*/
#define DSPI_PUSHR_CTCNT  0x0   /* 0 Do not clear the TCR[SPI_TCNT] field */
#define DSPI_PUSHR_EOQ    0x1   /* The SPI data is the last data to transfer */
#define DSPI_PUSHR_CTAR   0x0   /* 000b CTAR0*/
#define DSPI_PUSHR_CONT   0x0   /* 0 Return PCSn signals to their inactive
                                   state between transfers */

// DSPI port alternate functions
#define DSPI_PIN_SSS_SCK 		0x3  /* SIUL2_MSCR SSS field */
#define DSPI_PIN_SSS_SOUT 		0x3  /* SIUL2_MSCR SSS field */
#define DSPI_PIN_SSS_SIN 		0x1  /* SIUL2_MSCR SSS field */
#define DSPI_PIN_SSS_CS0 		0x3  /* SIUL2_MSCR SSS field */

//DSPI ports
#define DSPI_PIN_PD4		52
#define DSPI_PIN_PD5		53
#define DSPI_PIN_MUX_PD5   368       /* MUX MSCR_MUX[880] (880-512 = 368) */
#define DSPI_PIN_PE5		69
#define DSPI_PIN_PE9		73

/* DSPI0 Protocol clock  */
#define DSPI_PROTOCOL_CLOCK   UC_DSPI_CLK1 /* The clock is set via BSP during
                                              platform initialization.*/

/* SCK Baud rate 1Mhz,  protocol clock (DSPI CLK1) = 80MHz */
/* SCK baud rate = (PROTOCOL_CLOCK/PBR)  [(1+DBR)/BR] */
#define DSPI_CTAR_DBR   0
#define DSPI_CTAR_PBR   2  /* Baud Rate Prescaler value is 5 */
#define DSPI_CTAR_BR    4  /* Baud rate scaler value is 16 */
#define DSPI_CTAR_FMSZ  15 /* Frame size is 16 bit */

/* DSPI Data received ISR Vector */
#define UC_DSPI0_ISR_RFDF 263

/* ============================================================================
 * DSPI EXTERN
 * ==========================================================================*/

extern uint16_t g_dspi_DataToSend;
extern uint32_t g_dspi_ReceivedData;

/* ============================================================================
 * DSPI API INTERFACE
 * ==========================================================================*/

void dspi_Init(void);
void dspi_SendData(void);

/* ============================================================================
 * DSPI CONFIGURATION
 * Example setting
 * ==========================================================================*/

#define DSPI_PUSHR_SEND_CFG \
	((DSPI_PUSHR_CONT<<31) |(DSPI_PUSHR_CTAR<<28)|(DSPI_PUSHR_EOQ<<27)| \
     (DSPI_PUSHR_CTCNT<<26)|(DSPI_PUSHR_PE<<25)  |(DSPI_PUSHR_PP<<24) | \
	 (DSPI_PUSHR_PCS<<16))

/* ============================================================================
 * DSPI CONFIGURATION CHECKS
 * ==========================================================================*/
/* SCK Baud rate 1Mhz,  protocol clock (DSPI CLK1) = 80MHz */
#if(DSPI_PROTOCOL_CLOCK != 80)
#error The example supports only DSPI_CLK1 = 80MHz, other protocol \
	   frequencies are not supported
#endif

#endif /* DSPI_H */
